<?php
/**
 * Created by David Wood for his "Theme Customizer"
 * talk at WordCamp Orlando, 2014.
 *
 * http://davidwood.ninja/
 *
 * GPL v3.0
 *
 * This file has an example of creating a section with a single option. It also
 * lists the most commonly used options and some not so common, but helpful ones.
 */

add_action( 'customize_register', 'wco_global_options' );

/**
 * @param WP_Customize_Manager $wp_customize
 */
function wco_global_options( $wp_customize ) {

	// Add a section to hold our controls
	$wp_customize->add_section(
	// Our section's unique ID
		'wco_global_options_section',
		// Our array of arguments
		array(
			// This is the title of our section
			'title'          => 'Global Options',
			// This is a simple description of the section
			'description'    => 'A section containing general, site-wide options',
			// This determines the order sections appear
			'priority'       => 1,
			// See http://codex.wordpress.org/Roles_and_Capabilities#Capability_vs._Role_Table
			'capability'     => 'edit_theme_options',
			// See http://codex.wordpress.org/Function_Reference/add_theme_support
			'theme_supports' => '',
		)
	);

	// Adds a setting
	$wp_customize->add_setting(
		// Our setting ID, used to retrieve the value
		'wco_address',
		// Our array of arguments
		array(
			// The default value for this setting
			'default' => '123 Main Street, Disney World',
			// Can be `theme_mod` or `option`, default is `theme_mod`
			'type'           => 'theme_mod',
			// See http://codex.wordpress.org/Roles_and_Capabilities#Capability_vs._Role_Table
			'capability'     => 'edit_theme_options',
			// See http://codex.wordpress.org/Function_Reference/add_theme_support
			'theme_supports' => 'post-thumbnails',
			// Determines how the update appears in the preview
			// can be 'refresh' (default) or 'postMessage' (requires custom JS)
			'transport'      => 'refresh',
		)
	);

	// Adds a control
	$wp_customize->add_control(
		// Our control ID, typically the same as our setting ID
		'wco_address',
		// Our array of arguments
		array(
			// The user visible name for this field
			'label'       => 'Address',
			// A description to help the user out, added 4.0
			'description' => 'The address in the header and footer',
			// This determines the order controls appear
			'priority'    => 1,
			// The section this control is in
			'section'     => 'wco_global_options_section',
			// Used (and required) for radio and select input types
			// 'choices'  => array(
				// 'value' => 'label'
			//),
			// Adds html attributes to the input element, key => value pair. Added 4.0
			'input_attrs' => array(
				'data-wco' => 'some test data value',
				'style' => 'color: darkorange',
			),
			// Field type, can be 'text', 'checkbox', 'radio', 'select', 'textarea', 'dropdown-pages'
			'type'        => 'text',
			// NOTE: As of 4.0, other <input> field types (such as 'email', 'tel' and 'date') are also supported.
		)
	);

}