<?php
/**
 * Created by David Wood for his "Theme Customizer"
 * talk at WordCamp Orlando, 2014.
 *
 * http://davidwood.ninja/
 *
 * GPL v3.0
 *
 * This file has an example of creating a section with a single option. It also
 * lists the most commonly used options and some not so common, but helpful ones.
 */

add_action( 'customize_register', 'wco_homepage_options' );

/**
 * @param WP_Customize_Manager $wp_customize
 */
function wco_homepage_options( $wp_customize ) {

	// Add a panel to hold sections
	$wp_customize->add_panel(
	// Our panel's unique ID
		'wco_homepage_options_panel',
		// Our arguments
		array(
			// Our panel's title
			'title'       => 'Homepage Options',
			// Our panel's description
			'description' => 'Homepage specific options, sorted by section',
			// Our panel's priority
			'priority'    => 3,
		)
	);

	// Add a section to hold controls
	$wp_customize->add_section(
	// Our sections unique ID
		'wco_homepage_section_1',
		// Our arguments
		array(
			// Our section's title
			'title'       => 'Featured Pages',
			// Our section's description
			'description' => 'Controls the featured pages',
			// The ID of the panel our section will appear in
			'panel'       => 'wco_homepage_options_panel',
			// Our section's priority
			'priority'    => 1,
		)
	);

	// Add a setting
	$wp_customize->add_setting(
		'wco_featured_page_1',
		array(
			'default' => 0,
		)
	);

	// Add a setting
	$wp_customize->add_setting(
		'wco_featured_page_2',
		array(
			'default' => 0,
		)
	);

	// Add a control
	$wp_customize->add_control(
		'wco_featured_page_1',
		array(
			'label'   => 'Featured Page 1',
			'type'    => 'dropdown-pages',
			'section' => 'wco_homepage_section_1',
		)
	);

	// Add a control
	$wp_customize->add_control(
		'wco_featured_page_2',
		array(
			'label'   => 'Featured Page 2',
			'type'    => 'dropdown-pages',
			'section' => 'wco_homepage_section_1',
		)
	);

	// Add a section to hold controls
	$wp_customize->add_section(
	// Our sections unique ID
		'wco_homepage_section_2',
		// Our arguments
		array(
			// Our section's title
			'title'    => 'Cool Bar',
			// The ID of the panel our section will appear in
			'panel'    => 'wco_homepage_options_panel',
			// Our section's priority
			'priority' => 2,
		)
	);

	// // Add a setting
	$wp_customize->add_setting(
		'wco_cool_bar',
		array(
			'default' => 50,
			'transport' => 'postMessage',
		)
	);

	// Add a control
	$wp_customize->add_control(
		'wco_cool_bar',
		array(
			'label'       => 'Cool Bar',
			'description' => 'Set the width of the cool bar',
			'type'        => 'range',
			'input_attrs'  => array(
				'min'  => 1,
				'max'  => 100,
				'step' => 1,
			),
			'section'     => 'wco_homepage_section_2',
		)
	);

	// Add a setting
	$wp_customize->add_setting(
		'wco_cool_bar_color',
		array(
			'default' => '#09314b',
			'transport' => 'postMessage',
		)
	);

	// Add a control
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
		// Our WP_Customize_Manager object
			$wp_customize,
			// Our control ID, typically same as setting ID
			'wco_cool_bar_color',
			// Our arguments
			array(
				// Displayed label for this field
				'label' => 'Cool bar color',
				// Section ID this control should appear in
				'section' => 'wco_homepage_section_2',
			)
		)
	);

}